@@ -7,12 +7,12 @@ use strict;
 
 package XML::Compile::SOAP::Server;
 use vars '$VERSION';
-$VERSION = '0.55';
+$VERSION = '0.58';
 
 use Log::Report 'xml-compile-soap', syntax => 'SHORT';
 
 
-sub new(@) { panic "protocol server not implemented" }
+sub new(@) { panic __PACKAGE__." only secundary in multiple inheritance" }
 sub init($) { shift }
 
 1;
